# Video Representation Extractor

![logo](logo.png)

Documentation at: [link](https://video-representations-extractor.gitlab.io/video-representations-extractor/).

See the usage and installation page: [link](https://video-representations-extractor.gitlab.io/video-representations-extractor/basics/introduction-and-installation.html#installation).

